aboutsummaryrefslogtreecommitdiff
path: root/engines/agos/intern.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/agos/intern.h')
-rw-r--r--engines/agos/intern.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/agos/intern.h b/engines/agos/intern.h
index 587eca621c..13ed39156f 100644
--- a/engines/agos/intern.h
+++ b/engines/agos/intern.h
@@ -24,7 +24,7 @@
#ifndef AGOS_INTERN_H
#define AGOS_INTERN_H
-namespace Simon {
+namespace AGOS {
struct Child {
Child *next;
@@ -257,6 +257,6 @@ enum GameIds {
GID_SWAMPY
};
-} // End of namespace Simon
+} // End of namespace AGOS
#endif